from sensor.Sensor import Sensor
from utils.datatypes import *
from utils import i18n

import time
import os
import commands

# RDG Border Sensor - based on LTVBorder
# Dave Masterson 2004

class RDGBorder(Sensor):

    def __init__(self, height="50", width="50", type="0", top="12", bottom="15", left="12", right="15", ctheme="bluegrey"): 
        global _; _ = i18n.Translator("rdg-border-sensor")

        self.__type   = int( type )
        self.__height = int( height )
        self.__width  = int( width )
        self.__top    = int( top )
        self.__bottom = int( bottom )
        self.__left   = int( left )
        self.__right  = int( right )
        self.__ctheme = ctheme

        home = os.getenv("HOME")
        if os.path.exists(home + "/.gdesklets/RDGThemes/"):
            self.__thdir = home + "/.gdesklets/RDGThemes/"
        else :
            self.__thdir = "/usr/share/gdesklets/RDGThemes/"

        Sensor.__init__(self)
        
        self._set_config_type("type", TYPE_INT, self.__type)
        self._set_config_type("width", TYPE_INT, self.__width)
        self._set_config_type("height", TYPE_INT, self.__height)
        self._set_config_type("theme", TYPE_STRING, self.__ctheme)
        self._set_config_type("sbg", TYPE_BOOL, 1)
        self._set_config_type("sbr", TYPE_BOOL, 1)

        self._watch_config(self.watch_config)
        self._add_timer(0, self.draw)
        
    def get_configurator(self):
        conf1 = self._new_configurator()
        conf1.set_name(_("Border Settings"))
        conf1.add_title(_("Border Configuration"))
        conf1.add_option(_("Type"), "type", _("Style of borders you want"),[["None",0],["Top",1],["Bottom",2],["Both",3]])
        conf1.add_spin(_("Height",), "height", _("Height of the desklet"),10,1000)
        conf1.add_spin(_("Width",), "width", _("Width of the desklet"),10,1000)
        conf1.add_checkbox(_("Show Background"), "sbg", _("Show the background or not"))
        conf1.add_checkbox(_("Show Border"), "sbr", _("Show the border or not"))
        conf1.add_title(_("Theme Configuration"))

        # get a list of installed themes
        themes = [[x,x] for x in os.listdir(self.__thdir) if os.path.isdir(self.__thdir + "/" + x)]
        print themes
        conf1.add_option(_("Theme"), "theme", _("Style of Border Theme you want"),themes)
        return conf1

    def draw(self):
        data = self._new_output()
        self.__height = self._get_config("height")
        self.__width  = self._get_config("width")
        self.__type   = self._get_config("type")
        self.__ctheme = self._get_config("theme")
        height = self.__height
        width  = self.__width
        left   = self.__left
        right  = self.__right
        
        top    = 0
        bottom = 0
        s_top  = 0
        s_bot  = 0

        if self.__type == 1 or self.__type == 3:
            top = self.__top
            s_top = 1

        if self.__type == 2 or self.__type == 3:
            bottom = self.__bottom
            s_bot = 1

        data.set("height", height)
        data.set("width", width)
        data.set("top", top)
        data.set("bottom", bottom)
        data.set("left", left)
        data.set("right", right)
        data.set("show-top", s_top)
        data.set("show-bottom", s_bot)
        data.set("sbg", self._get_config("sbg"))
        data.set("sbr", self._get_config("sbr"))
        data.set("rightedge", left+width)
        data.set("bottomedge", top+height)
        data.set("i-height", height-10)
        data.set("i-width", width-10)
        data.set("i-left", left+5)
        data.set("i-top", top+5)
        data.set("tr", self.__thdir + "/" + self.__ctheme + "/tr.png")
        data.set("te", self.__thdir + "/" + self.__ctheme + "/te.png")
        data.set("tl", self.__thdir + "/" + self.__ctheme + "/tl.png")
        data.set("le", self.__thdir + "/" + self.__ctheme + "/le.png")
        data.set("bl", self.__thdir + "/" + self.__ctheme + "/bl.png")
        data.set("be", self.__thdir + "/" + self.__ctheme + "/be.png")
        data.set("br", self.__thdir + "/" + self.__ctheme + "/br.png")
        data.set("re", self.__thdir + "/" + self.__ctheme + "/re.png")
        data.set("bg", self.__thdir + "/" + self.__ctheme + "/bg.png")

        self._send_output(data)

    def watch_config(self,key,value):
        self.draw()

def new_sensor(args): return apply(RDGBorder, args)
